%define _buildid .10

%global py26nvr python26-requests-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr python27-requests-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

# The tests succeed if run locally, but fail in koji.
# They require an active network connection to query httpbin.org
%bcond_with tests # without

%global upstream_name requests

Name: python-requests
Version: 1.2.3
Release: 5%{?_buildid}%{?dist}
Summary: HTTP library, written in Python, for human beings
Group: System Environment/Libraries
License: ASL 2.0
URL: http://pypi.python.org/pypi/%{upstream_name}
Source0: http://pypi.python.org/packages/source/r/%{upstream_name}/%{upstream_name}-%{version}.tar.gz
# Explicitly use the system certificates in ca-certificates.
# https://bugzilla.redhat.com/show_bug.cgi?id=904614
Patch0: python-requests-system-cert-bundle.patch
# Unbundle python-charade (a fork of python-chardet).
# https://bugzilla.redhat.com/show_bug.cgi?id=904623
Patch1: python-requests-system-chardet-not-charade.patch
# Unbundle python-charade (a fork of python-urllib3).
# https://bugzilla.redhat.com/show_bug.cgi?id=904623
Patch2: python-requests-system-urllib3.patch
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python26
BuildRequires: python27

%description
Most existing Python modules for sending HTTP requests are extremely verbose and 
cumbersome. Python's built-in urllib2 module provides most of the HTTP 
capabilities you should need, but the API is thoroughly broken. This library is 
designed to make HTTP requests easy for developers.

%package -n python26-requests
Summary: HTTP library, written in Python, for human beings
BuildRequires: python26-devel
BuildRequires: python26-chardet
BuildRequires: python26-urllib3
BuildRequires: python26-ordereddict
Requires: ca-certificates
Requires: python26-chardet
Requires: python26-urllib3 >= 1.7
Requires: python26-ordereddict
Provides: python-requests = %{version}-%{release}
Obsoletes: python-%{upstream_name} <= 1.2.3-5.7.amzn1

%description -n python26-requests
Most existing Python modules for sending HTTP requests are extremely verbose and 
cumbersome. Python's built-in urllib2 module provides most of the HTTP 
capabilities you should need, but the API is thoroughly broken. This library is 
designed to make HTTP requests easy for developers.

This package is meant to be used with Python 2.6.

%package -n python27-requests
Summary: HTTP library, written in Python, for human beings
BuildRequires: python27-devel
BuildRequires: python27-chardet
BuildRequires: python27-urllib3
Requires: ca-certificates
Requires: python27-chardet
Requires: python27-urllib3 >= 1.7

%description -n python27-requests
Most existing Python modules for sending HTTP requests are extremely verbose and 
cumbersome. Python's built-in urllib2 module provides most of the HTTP 
capabilities you should need, but the API is thoroughly broken. This library is 
designed to make HTTP requests easy for developers.

This package is meant to be used with Python 2.7.

%prep
%setup -q -n %{upstream_name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Unbundle the certificate bundle from mozilla.
rm -v %{upstream_name}/cacert.pem

%build
rm -rf %{py26builddir}
mkdir -p %{py26builddir}
cp -a * %{py26builddir}
pushd %{py26builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python26} setup.py build 
popd

rm -rf %{py27builddir}
mkdir -p %{py27builddir}
cp -a * %{py27builddir}
pushd %{py27builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python27} setup.py build 
popd
pushd %{py26builddir}
# Unbundle chardet and urllib3.  Patch1 switches usage to system versions.
rm -r build/lib/%{upstream_name}/packages
popd
pushd %{py27builddir}
# Unbundle chardet and urllib3.  Patch1 switches usage to system versions.
rm -r build/lib/%{upstream_name}/packages
popd

%install
rm -rf %{buildroot}

pushd %{py26builddir}
%{__python26} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd
%{__python26_shebang} %{buildroot}%{python26_sitelib}/%{upstream_name}/certs.py

pushd %{py27builddir}
%{__python27} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd
%{__python27_shebang} %{buildroot}%{python27_sitelib}/%{upstream_name}/certs.py

%check
%if %{with tests}
pushd %{py26builddir}
%{__python26} test_requests.py
popd
pushd %{py27builddir}
%{__python27} test_requests.py
popd
%endif

%clean
rm -rf %{buildroot}
rm -rf %{py26builddir}
rm -rf %{py27builddir}

%files -n python26-requests
%doc NOTICE LICENSE README.rst HISTORY.rst
%{python26_sitelib}/*

%files -n python27-requests
%doc NOTICE LICENSE README.rst HISTORY.rst
%{python27_sitelib}/*

%changelog
* Thu Feb 5 2015 Tom Kirchner <tjk@amazon.com>
- Build for multiple python versions

* Thu Aug 29 2013 Lee Trager <ltrager@amazon.com>
- import source package F19/python-requests-1.2.3-5.fc19

* Mon Aug 26 2013 Rex Dieter <rdieter@fedoraproject.org> 1.2.3-5
- fix versioned dep on python-urllib3

* Mon Aug 26 2013 Ralph Bean <rbean@redhat.com> - 1.2.3-4
- Explicitly versioned the requirements on python-urllib3.

* Thu Aug 22 2013 Ralph Bean <rbean@redhat.com> - 1.2.3-3
- Release bump for a coupled update with python-urllib3.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jul 01 2013 Ralph Bean <rbean@redhat.com> - 1.2.3-1
- Latest upstream.
- Fixed bogus date in changelog.

* Tue Jun 11 2013 Ralph Bean <rbean@redhat.com> - 1.1.0-4
- Correct a rhel conditional on python-ordereddict

* Mon May 6 2013 Lee Trager <ltrager@amazon.com>
- import source package EPEL6/python-requests-1.1.0-3.el6

* Thu Feb 28 2013 Ralph Bean <rbean@redhat.com> - 1.1.0-3
- Unbundled python-urllib3.  Using system python-urllib3 now.
- Conditionally include python-ordereddict for el6.

* Wed Feb 27 2013 Ralph Bean <rbean@redhat.com> - 1.1.0-2
- Unbundled python-charade/chardet.  Using system python-chardet now.
- Removed deprecated comments and actions against oauthlib unbundling.
  Those are no longer necessary in 1.1.0.
- Added links to bz tickets over Patch declarations.

* Tue Feb 26 2013 Lee Trager <ltrager@amazon.com>
- Disable self tests since they require web access
- Update to 1.1.0 from upstream

* Tue Feb 26 2013 Ralph Bean <rbean@redhat.com> - 1.1.0-1
- Latest upstream.
- Relicense to ASL 2.0 with upstream.
- Removed cookie handling patch (fixed in upstream tarball).
- Updated cert unbundling patch to match upstream.
- Added check section, but left it commented out for koji.

* Fri Feb  8 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 0.14.1-4
- Let brp_python_bytecompile run again, take care of the non-python{2,3} modules
  by removing them from the python{,3}-requests package that they did not belong
  in.
- Use the certificates in the ca-certificates package instead of the bundled one
  + https://bugzilla.redhat.com/show_bug.cgi?id=904614
- Fix a problem with cookie handling
  + https://bugzilla.redhat.com/show_bug.cgi?id=906924

* Mon Oct 22 2012 Arun S A G <sagarun@gmail.com>  0.14.1-1
- Updated to latest upstream release

* Sun Jun 10 2012 Arun S A G <sagarun@gmail.com> 0.13.1-1
- Updated to latest upstream release 0.13.1
- Use system provided ca-certificates
- No more async requests use grrequests https://github.com/kennethreitz/grequests
- Remove gevent as it is no longer required by requests

* Tue May 8 2012 Cristian Gafton <gafton@amazon.com>
- import source package EPEL6/python-requests-0.11.1-2.el6
- setup complete for package python-requests

* Sun Apr 01 2012 Arun S A G <sagarun@gmail.com> 0.11.1-1
- Updated to upstream release 0.11.1

* Thu Mar 29 2012 Arun S A G <sagarun@gmail.com> 0.10.6-3
- Support building package for EL6

* Tue Mar 27 2012 Rex Dieter <rdieter@fedoraproject.org> 0.10.6-2
- +python3-requests pkg

* Sat Mar 3 2012 Arun SAG <sagarun@gmail.com> - 0.10.6-1
- Updated to new upstream version

* Sat Jan 21 2012 Arun SAG <sagarun@gmail.com> - 0.9.3-1
- Updated to new upstream version 0.9.3
- Include python-gevent as a dependency for requests.async
- Clean up shebangs in requests/setup.py,test_requests.py and test_requests_ext.py

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Nov 27 2011 Arun SAG <sagarun@gmail.com> - 0.8.2-1
- New upstream version
- keep alive support
- complete removal of cookiejar and urllib2

* Thu Nov 10 2011 Arun SAG <sagarun@gmail.com> - 0.7.6-1
- Updated to new upstream release 0.7.6

* Thu Oct 20 2011 Arun SAG <sagarun@gmail.com> - 0.6.6-1
- Updated to version 0.6.6

* Fri Aug 26 2011 Arun SAG <sagarun@gmail.com> - 0.6.1-1
- Updated to version 0.6.1

* Sat Aug 20 2011 Arun SAG <sagarun@gmail.com> - 0.6.0-1
- Updated to latest version 0.6.0

* Mon Aug 15 2011 Arun SAG <sagarun@gmail.com> - 0.5.1-2
- Remove OPT_FLAGS from build section since it is a noarch package
- Fix use of mixed tabs and space
- Remove extra space around the word cumbersome in description

* Sun Aug 14 2011 Arun SAG <sagarun@gmail.com> - 0.5.1-1
- Initial package
